import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState } from 'react';
import { createRoot } from 'react-dom/client';
import { ServiceManager } from '@jupyterlab/services';
import { Box, SegmentedControl } from '@primer/react';
import { createServiceManagerLite, createServerSettings, getJupyterServerUrl, getJupyterServerToken, ServiceManagerLess } from '../jupyter';
import { useNotebookStore, Notebook } from './../components';
import { JupyterReactTheme } from '../theme';
import nbformat from './notebooks/NotebookExample1.ipynb.json';
const NOTEBOOK_ID = 'notebook-mutations-id';
const NotebookMutations = () => {
    const [index, setIndex] = useState(0);
    const [readonly, setReadonly] = useState(true);
    const [serverless, setServerless] = useState(true);
    const [lite, setLite] = useState(false);
    const [serviceManager, setServiceManager] = useState(new ServiceManagerLess());
    const notebookStore = useNotebookStore();
    const notebook = notebookStore.selectNotebook(NOTEBOOK_ID);
    const changeIndex = (index) => {
        setIndex(index);
        switch (index) {
            case 0: {
                setReadonly(true);
                setServerless(true);
                setLite(false);
                setServiceManager(new ServiceManagerLess());
                break;
            }
            case 1: {
                setReadonly(false);
                setServerless(true);
                setLite(true);
                createServiceManagerLite().then(serviceManager => {
                    console.log('Created Service Manager Lite', serviceManager);
                    setServiceManager(serviceManager);
                });
                break;
            }
            case 2: {
                setReadonly(false);
                setServerless(false);
                setLite(false);
                const serverSettings = createServerSettings(getJupyterServerUrl(), getJupyterServerToken());
                const serviceManager = new ServiceManager({ serverSettings });
                setServiceManager(serviceManager);
                break;
            }
        }
    };
    return (_jsxs(JupyterReactTheme, { children: [_jsxs(Box, { display: "flex", children: [_jsx(Box, { children: _jsxs(SegmentedControl, { onChange: index => changeIndex(index), "aria-label": "jupyter-react-example", children: [_jsx(SegmentedControl.Button, { defaultSelected: index === 0, children: "Readonly" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 1, children: "Browser Kernel" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 2, children: "OSS Kernel" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 3, disabled: true, children: "Datalayer CPU Kernel" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 4, disabled: true, children: "Datalayer GPU Kernel" })] }) }), _jsxs(Box, { ml: 3, children: ["Readonly: ", String(notebook?.adapter?.readonly)] }), _jsxs(Box, { ml: 3, children: ["Serverless: ", String(notebook?.adapter?.serverless)] }), _jsxs(Box, { ml: 3, children: ["Lite: ", String(notebook?.adapter?.lite)] }), _jsxs(Box, { ml: 3, children: ["Kernel: ", notebook?.adapter?.kernel?.id, " (", notebook?.adapter?.kernel?.info?.banner, ")"] }), _jsxs(Box, { ml: 3, children: ["Service Manager Ready: ", String(notebook?.adapter?.serviceManager.isReady)] }), _jsxs(Box, { ml: 3, children: ["Service Manager URL: ", notebook?.adapter?.serviceManager.serverSettings.baseUrl] })] }), _jsx(Notebook, { id: NOTEBOOK_ID, lite: lite, nbformat: nbformat, readonly: readonly, serverless: serverless, serviceManager: serviceManager, height: "calc(100vh - 2.6rem)" })] }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(NotebookMutations, {}));
//# sourceMappingURL=NotebookMutations.js.map